@@ -6,7 +6,7 @@ use warnings;
 use DateTime::Locale::Util qw( parse_locale_code );
 use Params::Validate qw( validate_pos );
 
-our $VERSION = '0.91';
+our $VERSION = '1.00';
 
 my @FormatLengths;
 
@@ -110,6 +110,10 @@ sub time_format_default {
     return $_[0]->time_format_medium;
 }
 
+sub datetime_format {
+    return $_[0]->{datetime_format_medium};
+}
+
 sub datetime_format_default {
     return $_[0]->datetime_format_medium;
 }
@@ -269,7 +273,7 @@ DateTime::Locale::FromData - Class for locale objects instantiated from pre-defi
 
 =head1 VERSION
 
-version 0.91
+version 1.00
 
 =head1 SYNOPSIS
 
@@ -482,20 +486,10 @@ The CLDR version from which this locale was generated.
 
 =back
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Richard Evans
-
-=item *
+=head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Dave Rolsky.
